@@ -1,7 +1,7 @@
 ;;; tramp-vc.el --- Version control integration for TRAMP.el
 
 ;; Copyright (C) 2000, 2001, 2002, 2003, 2004,
-;;   2005, 2006 Free Software Foundation, Inc.
+;;   2005, 2006, 2007 Free Software Foundation, Inc.
 
 ;; Author: Daniel Pittman <daniel@danann.net>
 ;; Keywords: comm, processes
@@ -31,8 +31,6 @@
 
 ;;; Code:
 
-(eval-when-compile
-  (require 'cl))
 (require 'vc)
 ;; Old VC defines vc-rcs-release in vc.el, new VC requires extra module.
 (unless (boundp 'vc-rcs-release)
